##########################
@{{ program }}@ - analysis
##########################

TIS analysis report for path ensemble @{{ ensemble }}@
generated by @{{ program }}@ version @{{ version }}@
on @{{ date }}@.

The main numerical results are given in the
tables in the section on tis-results_.

.. _figure-results:

Results in figures
==================

The following figures were generated by the
analysis:

.. _prob-figures-output:

Probability figures
-------------------

.. image:: @{{ figures['pcross'] }}@
   :width: 30%
.. image:: @{{ figures['prun'] }}@
   :width: 30%
.. image:: @{{ figures['perror'] }}@
   :width: 30%

.. _len-shoot-figures-output:

Length and shoots figures
-------------------------

.. image:: @{{ figures['lpath'] }}@
   :width: 45%
.. image:: @{{ figures['shoots'] }}@
   :width: 45%


.. _tis-results:

TIS results for ensemble: @{{ ensemble }}@
==========================================

@{{ tables['interfaces'] }}@

@{{ tables['probability'] }}@

@{{ tables['efficiency'] }}@
